<?php
/**
 * @package            Joomla
 * @subpackage         Documents Seller
 * @author             Tuan Pham Ngoc
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

/**
 * Layout variables
 *
 * @var array     $items
 * @var DSFConfig $config
 * @var int       $Itemid
 */

if ($config->show_detail_in_popup)
{
	DMSHelperJquery::colorbox('a.dms-modal');
	$popup = 'class="dms-modal"';
}
else
{
    $popup = '';
}

$dateFormat = 'F d Y';
?>
<table class="table table-striped table-bordered">
    <thead>
    <tr>
        <th>
            <?php echo Text::_('DMS_DOCUMENT'); ?>
        </th>
        <th class="col_price hidden-phone" style="text-align: right;">
            <?php echo Text::_('DMS_PRICE').' ('.$config->currency_symbol.')'; ?>
        </th>
        <th class="order_date center hidden-phone">
            <?php echo Text::_('DMS_ORDER_DATE');  ?>
        </th>
        <?php
        if ($config->show_download_in)
        {
        ?>
            <th class="col_restriction hidden-phone">
                <?php echo Text::_('DMS_RESTRICTION'); ?>
            </th>
        <?php
        }
        ?>
        <th class="order_date center hidden-phone">
		    <?php echo Text::_('DMS_EXPIRED_DATE');  ?>
        </th>
        <th class="col_download center">
            <?php echo Text::_('DMS_DOWNLOAD'); ?>
        </th>
        <?php
        if (false && $config->activate_invoice_feature)
        {
        ?>
            <th width="5%" class="dms-invoice-col" nowrap="nowrap">
                <?php echo Text::_('DMS_INVOICE'); ?>
            </th>
        <?php
        }
        ?>
    </tr>
    </thead>
    <tbody>
    <?php
    $total = 0;
    for ($i = 0, $n = count($items); $i < $n; $i++)
    {
	    $item = $items[$i];

	    if ($config->show_detail_in_popup)
	    {
		    $url = Route::_(DMSHelperRoute::getDocumentRoute($item->id, 0, $Itemid, '&tmpl=component'));
	    }
	    else
	    {
		    $url = Route::_(DMSHelperRoute::getDocumentRoute($item->id, 0, $Itemid));
	    }

	    if ($item->prevent_download_type == 0)
	    {
		    $canDownload = true;
	    }
        elseif ($item->prevent_download_type == 1 && ($item->number_downloads > $item->downloaded))
	    {
		    $canDownload = true;
	    }
	    else if ($item->prevent_download_type == 2 && ($item->number_days >= $item->days_different))
	    {
		    $canDownload = true;
	    }
	    else
	    {
		    $canDownload = false;
	    }
        ?>
        <tr>
            <td>
                <a href="<?php echo $url; ?>" <?php echo $popup; ?> ><?php echo $item->title; ?></a><sup><?php echo $item->version;?></sup>
            </td>
            <td style="text-align: right;" class="hidden-phone">
                <?php echo DMSHelperHtml::formatPrice($config, $item->price); ?>
            </td>
            <td style="text-align: center;" class="hidden-phone">
                <?php echo HTMLHelper::_('date', $item->payment_date, $dateFormat) ; ?>
            </td>
            <?php
            if ($config->show_download_in)
            {
            ?>
                <td class="hidden-phone">
                    <?php
                    if ($item->prevent_download_type == 1)
                    {
                        $restriction = $item->number_downloads.' '.Text::_('DMS_DOWNLOADS') ;
                    }
                    elseif ($item->prevent_download_type == 2)
                    {
                        $restriction = $item->number_days .' '. Text::_('DMS_DAYS');
                    }
                    else
                    {
                        $restriction = Text::_('DMS_LIFETIME') ;
                    }
                    ?>
                    <strong><?php echo $restriction ; ?></strong>
                </td>
            <?php
            }
            ?>
            <td class="center">
                <?php
                    if ($item->number_days > 0)
                    {
                        $date = Factory::getDate($item->payment_date);
	                    $date->modify('+' . $item->number_days . ' days');

	                    if ($canDownload)
	                    {
		                    echo $date->format($dateFormat);
	                    }
	                    else
                        {
                        ?>
                            <span style="color: red"><?php echo $date->format($dateFormat); ?></span>
                        <?php
                        }
                    }
                ?>
            </td>
            <td class="center">
                <?php
                if ($canDownload)
                {
	                $downloadLink = Route::_('index.php?option=com_dms&task=download&id=' . $item->id . '&order_id=' . $item->order_id . '&Itemid=' . $Itemid);
                ?>
                    <a href="<?php echo $downloadLink; ?>"><strong><?php echo Text::_('DMS_DOWNLOAD'); ?></strong></a>
                <?php
                }
                else
                {
	                echo '<span class="required">' . Text::_('DMS_EXPIRED') . '</span>';
                }
                ?>
            </td>
            <?php
            if (false && $config->activate_invoice_feature && $item->invoice_number > 0)
            {
            ?>
                <td class="center"><a href="index.php?option=com_dms&task=download_invoice&order_id=<?php echo $item->order_id ?>"><?php echo DMSHelper::formatInvoiceNumber($item->order_id, $config); ?></a></td>
            <?php
            }
            ?>
        </tr>
        <?php
    }
    ?>
    </tbody>
</table>
